.. warning::
    Client version 2 is obsolete, please use Client version 3 instead.


Resources
=========

Project
-------
see entity attributes at :ref:`project-attributes`.

.. autoclass:: copr.client_v2.resources.Project
   :members:

.. autoclass:: copr.client_v2.resources.ProjectList
   :members:

Project chroot
--------------
see entity attributes at :ref:`project-chroot-attributes`.

.. autoclass:: copr.client_v2.resources.ProjectChroot
   :members:

.. autoclass:: copr.client_v2.resources.ProjectChrootList
   :members:

Build
-----
see entity attributes at :ref:`build-attributes`.

.. autoclass:: copr.client_v2.resources.Build
   :members:

.. autoclass:: copr.client_v2.resources.BuildList
   :members:

Build task
----------
see entity attributes at :ref:`build-task-attributes`.

.. autoclass:: copr.client_v2.resources.BuildTask
   :members:

.. autoclass:: copr.client_v2.resources.BuildTaskList
   :members:

Mock chroot
-----------
see entity attributes at :ref:`mock-chroot-attributes`.

.. autoclass:: copr.client_v2.resources.MockChroot
   :members:

.. autoclass:: copr.client_v2.resources.MockChrootList
   :members:

Operation result
----------------
.. autoclass:: copr.client_v2.resources.OperationResult
   :members:
